<?php
session_start();

// Verificar si el usuario está autenticado
if (!isset($_SESSION['user_id'])) {
    header('Location: login.php');
    exit();
}

// Datos del usuario
$user_id = $_SESSION['user_id'];
$name = $_SESSION['name'];
$phone = $_SESSION['phone'];

// Conexión a la base de datos
require_once 'config.php';

// Obtener conversaciones del usuario (chats existentes)
$chats_query = "
    SELECT 
        u.id, u.name, u.phone,
        (SELECT message FROM messages 
         WHERE (sender_id = ? AND receiver_id = u.id) OR (sender_id = u.id AND receiver_id = ?) 
         ORDER BY timestamp DESC LIMIT 1) as last_message,
        (SELECT timestamp FROM messages 
         WHERE (sender_id = ? AND receiver_id = u.id) OR (sender_id = u.id AND receiver_id = ?) 
         ORDER BY timestamp DESC LIMIT 1) as last_timestamp,
        (SELECT COUNT(*) FROM messages 
         WHERE sender_id = u.id AND receiver_id = ? AND `read` = 0) as unread_count
    FROM 
        users u
    WHERE 
        u.id != ? AND
        EXISTS (
            SELECT 1 FROM messages 
            WHERE (sender_id = ? AND receiver_id = u.id) OR (sender_id = u.id AND receiver_id = ?)
        )
    ORDER BY 
        last_timestamp DESC
";
$chats_stmt = $conn->prepare($chats_query);
$chats_stmt->bind_param("iiiiiiii", $user_id, $user_id, $user_id, $user_id, $user_id, $user_id, $user_id, $user_id);
$chats_stmt->execute();
$chats_result = $chats_stmt->get_result();
$chats = [];
while ($row = $chats_result->fetch_assoc()) {
    $chats[] = $row;
}

// Obtener todos los usuarios (para el buscador)
$users_query = "SELECT id, name, phone FROM users WHERE id != ? ORDER BY name";
$users_stmt = $conn->prepare($users_query);
$users_stmt->bind_param("i", $user_id);
$users_stmt->execute();
$users_result = $users_stmt->get_result();
$users = [];
while ($row = $users_result->fetch_assoc()) {
    $users[] = $row;
}
?>
<!DOCTYPE html>
<html lang="es">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>FlyChat - Dashboard</title>
    <link href="https://cdnjs.cloudflare.com/ajax/libs/tailwindcss/2.2.19/tailwind.min.css" rel="stylesheet">
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style>
        .blue-gradient {
            background: linear-gradient(135deg, #0088cc 0%, #0055a5 100%);
        }
        .chat-item:hover {
            background-color: rgba(59, 130, 246, 0.05);
        }
        .chat-item.active {
            background-color: rgba(59, 130, 246, 0.1);
        }
    </style>
</head>
<body class="bg-gray-100 h-screen flex flex-col">
    <header class="blue-gradient text-white p-4 flex justify-between items-center">
        <h1 class="text-xl font-bold">FlyChat</h1>
        <div class="flex items-center">
            <button id="menu-btn" class="p-2">
                <i class="fas fa-bars"></i>
            </button>
        </div>
    </header>
    
    <!-- Menú lateral (oculto por defecto en móvil) -->
    <div id="side-menu" class="fixed inset-0 bg-black bg-opacity-50 z-50 hidden">
        <div class="w-64 h-full bg-white flex flex-col">
            <div class="blue-gradient p-4 text-white flex items-center">
                <div class="w-12 h-12 rounded-full bg-blue-300 flex items-center justify-center text-blue-800 font-bold mr-3">
                    <span id="user-initials"><?php echo strtoupper(substr($name, 0, 1)); ?></span>
                </div>
                <div>
                    <h2 id="user-name" class="font-bold"><?php echo htmlspecialchars($name); ?></h2>
                    <p id="user-phone" class="text-sm text-blue-100"><?php echo htmlspecialchars($phone); ?></p>
                </div>
            </div>
            <div class="flex-1 p-2">
                <a href="#" class="block p-3 rounded hover:bg-gray-100">
                    <i class="fas fa-user-friends mr-2"></i> Contactos
                </a>
                <a href="#" class="block p-3 rounded hover:bg-gray-100">
                    <i class="fas fa-cog mr-2"></i> Configuración
                </a>
                <a href="#" class="block p-3 rounded hover:bg-gray-100">
                    <i class="fas fa-question-circle mr-2"></i> Ayuda
                </a>
            </div>
            <div class="p-3 border-t">
                <a href="logout.php" class="block w-full py-2 px-4 text-red-500 rounded hover:bg-red-50 text-left">
                    <i class="fas fa-sign-out-alt mr-2"></i> Cerrar sesión
                </a>
            </div>
        </div>
        <div class="flex-1" onclick="closeSideMenu()"></div>
    </div>
    
    <!-- Buscador -->
    <div class="p-3 bg-white border-b">
        <div class="relative">
            <input type="text" id="search-input" placeholder="Buscar usuarios o conversaciones..." 
                   class="w-full pl-10 pr-4 py-2 rounded-full border focus:outline-none focus:ring-2 focus:ring-blue-500">
            <div class="absolute left-3 top-2 text-gray-400">
                <i class="fas fa-search"></i>
            </div>
        </div>
    </div>
    
    <!-- Lista de chats -->
    <div class="flex-1 overflow-y-auto bg-white">
        <!-- Contenedor de chats existentes -->
        <div id="chats-container">
            <?php if (empty($chats)): ?>
                <div class="px-4 py-2 text-sm font-semibold text-gray-500 uppercase">Conversaciones recientes</div>
                <div class="p-4 text-center text-gray-500">
                    No tienes conversaciones recientes
                </div>
            <?php else: ?>
                <div class="px-4 py-2 text-sm font-semibold text-gray-500 uppercase">Conversaciones recientes</div>
                <?php foreach ($chats as $chat): ?>
                    <?php 
                    $initials = strtoupper(substr($chat['name'], 0, 1));
                    $timestamp = $chat['last_timestamp'] ? date('H:i', strtotime($chat['last_timestamp'])) : '';
                    if ($chat['last_timestamp'] && date('Y-m-d', strtotime($chat['last_timestamp'])) != date('Y-m-d')) {
                        $timestamp = date('d/m', strtotime($chat['last_timestamp']));
                    }
                    ?>
                    <div class="chat-item flex p-3 border-b cursor-pointer" data-user-id="<?php echo $chat['id']; ?>" onclick="openChat(<?php echo $chat['id']; ?>)">
                        <div class="w-12 h-12 rounded-full bg-blue-100 flex items-center justify-center text-blue-800 font-bold mr-3">
                            <span><?php echo $initials; ?></span>
                        </div>
                        <div class="flex-1">
                            <div class="flex justify-between">
                                <h3 class="font-semibold"><?php echo htmlspecialchars($chat['name']); ?></h3>
                                <span class="text-xs text-gray-500"><?php echo $timestamp; ?></span>
                            </div>
                            <p class="text-sm text-gray-600 truncate"><?php echo $chat['last_message'] ? htmlspecialchars($chat['last_message']) : ''; ?></p>
                        </div>
                        <?php if ($chat['unread_count'] > 0): ?>
                        <div class="flex-shrink-0 self-center ml-2">
                            <span class="bg-blue-500 text-white text-xs font-medium px-2 py-1 rounded-full"><?php echo $chat['unread_count']; ?></span>
                        </div>
                        <?php endif; ?>
                    </div>
                <?php endforeach; ?>
            <?php endif; ?>
        </div>
        
        <!-- Contenedor para todos los usuarios -->
        <div id="all-users-container" class="<?php echo empty($chats) ? '' : 'hidden'; ?>">
            <div class="px-4 py-2 text-sm font-semibold text-gray-500 uppercase">Todos los usuarios</div>
            <?php foreach ($users as $user): ?>
                <?php $initials = strtoupper(substr($user['name'], 0, 1)); ?>
                <div class="chat-item flex p-3 border-b cursor-pointer" data-user-id="<?php echo $user['id']; ?>" onclick="openChat(<?php echo $user['id']; ?>)">
                    <div class="w-12 h-12 rounded-full bg-blue-100 flex items-center justify-center text-blue-800 font-bold mr-3">
                        <span><?php echo $initials; ?></span>
                    </div>
                    <div class="flex-1">
                        <div class="flex justify-between">
                            <h3 class="font-semibold"><?php echo htmlspecialchars($user['name']); ?></h3>
                        </div>
                        <p class="text-sm text-gray-600 truncate"><?php echo htmlspecialchars($user['phone']); ?></p>
                    </div>
                </div>
            <?php endforeach; ?>
        </div>
        
        <!-- Contenedor para resultados de búsqueda -->
        <div id="search-results" class="hidden">
            <div class="px-4 py-2 text-sm font-semibold text-gray-500 uppercase">Resultados de búsqueda</div>
            <div id="search-results-container"></div>
        </div>
        
        <!-- Mensaje cuando no hay resultados de búsqueda -->
        <div id="no-results" class="hidden p-8 text-center">
            <div class="text-gray-400 mb-3">
                <i class="fas fa-search text-4xl"></i>
            </div>
            <p class="text-gray-500">No se encontraron resultados</p>
        </div>
    </div>
    
    <!-- Botón flotante para buscar usuarios -->
    <div class="fixed right-4 bottom-4">
        <button id="search-users-btn" class="w-14 h-14 rounded-full blue-gradient text-white flex items-center justify-center shadow-lg">
            <i class="fas fa-search text-lg"></i>
        </button>
    </div>
    
    <script>
        // Variables globales
        let currentUser = {
            id: <?php echo $user_id; ?>,
            name: "<?php echo addslashes($name); ?>",
            phone: "<?php echo addslashes($phone); ?>",
            initials: "<?php echo strtoupper(substr($name, 0, 1)); ?>"
        };
        
        // Inicialización al cargar la página
        document.addEventListener('DOMContentLoaded', function() {
            // Configurar eventos
            document.getElementById('menu-btn').addEventListener('click', openSideMenu);
            document.getElementById('search-input').addEventListener('input', searchUsers);
            document.getElementById('search-users-btn').addEventListener('click', toggleAllUsers);
        });
        
        function openSideMenu() {
            document.getElementById('side-menu').classList.remove('hidden');
        }
        
        function closeSideMenu() {
            document.getElementById('side-menu').classList.add('hidden');
        }
        
        function toggleAllUsers() {
            const chatsContainer = document.getElementById('chats-container');
            const allUsersContainer = document.getElementById('all-users-container');
            const searchResults = document.getElementById('search-results');
            const noResults = document.getElementById('no-results');
            
            // Limpiar búsqueda
            document.getElementById('search-input').value = '';
            
            // Ocultar resultados de búsqueda
            searchResults.classList.add('hidden');
            noResults.classList.add('hidden');
            
            // Alternar entre chats y todos los usuarios
            if (allUsersContainer.classList.contains('hidden')) {
                chatsContainer.classList.add('hidden');
                allUsersContainer.classList.remove('hidden');
                document.getElementById('search-users-btn').innerHTML = '<i class="fas fa-comment text-lg"></i>';
            } else {
                chatsContainer.classList.remove('hidden');
                allUsersContainer.classList.add('hidden');
                document.getElementById('search-users-btn').innerHTML = '<i class="fas fa-search text-lg"></i>';
            }
        }
        
        function searchUsers() {
            const query = document.getElementById('search-input').value.toLowerCase();
            const chatsContainer = document.getElementById('chats-container');
            const allUsersContainer = document.getElementById('all-users-container');
            const searchResults = document.getElementById('search-results');
            const searchResultsContainer = document.getElementById('search-results-container');
            const noResults = document.getElementById('no-results');
            
            if (query === '') {
                // Mostrar vista normal
                if (allUsersContainer.classList.contains('hidden')) {
                    chatsContainer.classList.remove('hidden');
                } else {
                    allUsersContainer.classList.remove('hidden');
                }
                searchResults.classList.add('hidden');
                noResults.classList.add('hidden');
                return;
            }
            
            // Buscar en todos los usuarios
            const userElements = document.querySelectorAll('#all-users-container .chat-item');
            searchResultsContainer.innerHTML = '';
            let foundResults = false;
            
            userElements.forEach(element => {
                const name = element.querySelector('h3').textContent.toLowerCase();
                const phone = element.querySelector('p').textContent.toLowerCase();
                
                if (name.includes(query) || phone.includes(query)) {
                    searchResultsContainer.appendChild(element.cloneNode(true));
                    foundResults = true;
                }
            });
            
            // Buscar en chats existentes
            const chatElements = document.querySelectorAll('#chats-container .chat-item');
            
            chatElements.forEach(element => {
                const name = element.querySelector('h3').textContent.toLowerCase();
                const message = element.querySelector('p').textContent.toLowerCase();
                
                if (name.includes(query) || message.includes(query)) {
                    // Verificar si ya existe en resultados
                    const userId = element.getAttribute('data-user-id');
                    const exists = searchResultsContainer.querySelector(`[data-user-id="${userId}"]`);
                    
                    if (!exists) {
                        searchResultsContainer.appendChild(element.cloneNode(true));
                        foundResults = true;
                    }
                }
            });
            
            // Mostrar/ocultar contenedores según resultados
            chatsContainer.classList.add('hidden');
            allUsersContainer.classList.add('hidden');
            
            if (foundResults) {
                searchResults.classList.remove('hidden');
                noResults.classList.add('hidden');
            } else {
                searchResults.classList.add('hidden');
                noResults.classList.remove('hidden');
            }
        }
        
        function openChat(userId) {
            window.location.href = 'chat.php?id=' + userId;
        }
    </script>
</body>
</html>