<?php
session_start();
header('Content-Type: application/json');

// Conexión a la base de datos
require_once 'config.php';

// Verificar si se recibieron los datos necesarios
if (!isset($_POST['phone']) || !isset($_POST['name']) || !isset($_POST['firebase_uid'])) {
    echo json_encode(['success' => false, 'message' => 'Faltan datos requeridos']);
    exit();
}

$phone = $conn->real_escape_string($_POST['phone']);
$name = $conn->real_escape_string($_POST['name']);
$firebase_uid = $conn->real_escape_string($_POST['firebase_uid']);

// Verificar si el usuario ya existe
$check_query = "SELECT id FROM users WHERE phone = ?";
$check_stmt = $conn->prepare($check_query);
$check_stmt->bind_param("s", $phone);
$check_stmt->execute();
$check_result = $check_stmt->get_result();

if ($check_result->num_rows > 0) {
    // Usuario ya existe
    $user = $check_result->fetch_assoc();
    
    // Actualizar información
    $update_query = "UPDATE users SET name = ?, last_login = NOW() WHERE id = ?";
    $update_stmt = $conn->prepare($update_query);
    $update_stmt->bind_param("si", $name, $user['id']);
    
    if ($update_stmt->execute()) {
        // Crear sesión
        $_SESSION['user_id'] = $user['id'];
        $_SESSION['name'] = $name;
        $_SESSION['phone'] = $phone;
        $_SESSION['firebase_uid'] = $firebase_uid;
        
        echo json_encode(['success' => true]);
    } else {
        echo json_encode(['success' => false, 'message' => 'Error al actualizar usuario']);
    }
    
    $update_stmt->close();
} else {
    // Insertar nuevo usuario
    $insert_query = "INSERT INTO users (phone, name) VALUES (?, ?)";
    $insert_stmt = $conn->prepare($insert_query);
    $insert_stmt->bind_param("ss", $phone, $name);
    
    if ($insert_stmt->execute()) {
        $user_id = $conn->insert_id;
        
        // Crear sesión
        $_SESSION['user_id'] = $user_id;
        $_SESSION['name'] = $name;
        $_SESSION['phone'] = $phone;
        $_SESSION['firebase_uid'] = $firebase_uid;
        
        echo json_encode(['success' => true]);
    } else {
        echo json_encode(['success' => false, 'message' => 'Error al registrar usuario']);
    }
    
    $insert_stmt->close();
}

$check_stmt->close();
$conn->close();
?>